@@ -19,25 +19,25 @@ use W3C::SOAP::WSDL::Document::Operation;
 
 extends 'W3C::SOAP::Document::Node';
 
-our $VERSION     = version->new('0.09');
+our $VERSION     = version->new('0.10');
 
 has style => (
     is         => 'rw',
     isa        => 'Str',
     builder    => '_style',
-    lazy_build => 1,
+    lazy       => 1,
 );
 has transport => (
     is         => 'rw',
     isa        => 'Str',
     builder    => '_transport',
-    lazy_build => 1,
+    lazy       => 1,
 );
 has operations => (
     is         => 'rw',
     isa        => 'ArrayRef[W3C::SOAP::WSDL::Document::Operation]',
     builder    => '_operations',
-    lazy_build => 1,
+    lazy       => 1,
 );
 
 sub _style {
@@ -77,12 +77,11 @@ __END__
 
 =head1 NAME
 
-W3C::SOAP::WSDL::Document::Binding - <One-line description of module's purpose>
+W3C::SOAP::WSDL::Document::Binding - Bindings for WSDL documents
 
 =head1 VERSION
 
-This documentation refers to W3C::SOAP::WSDL::Document::Binding version 0.09.
-
+This documentation refers to W3C::SOAP::WSDL::Document::Binding version 0.10.
 
 =head1 SYNOPSIS
 
@@ -95,10 +94,8 @@ This documentation refers to W3C::SOAP::WSDL::Document::Binding version 0.09.
 
 =head1 DESCRIPTION
 
-A full description of the module and its features.
-
-May include numerous subsections (i.e., =head2, =head3, etc.).
-
+A C<W3C::SOAP::WSDL::Document::Binding> represents the bindings tags in a WSDL
+document.
 
 =head1 SUBROUTINES/METHODS
 
