@@ -18,13 +18,13 @@ use English qw/ -no_match_vars /;
 
 extends 'W3C::SOAP::Document::Node';
 
-our $VERSION     = version->new('0.09');
+our $VERSION     = version->new('0.10');
 
 has operations => (
     is         => 'rw',
     isa        => 'ArrayRef[W3C::SOAP::WSDL::Document::Operation]',
     builder    => '_operations',
-    lazy_build => 1,
+    lazy       => 1,
 );
 
 sub _operations {
@@ -48,11 +48,11 @@ __END__
 
 =head1 NAME
 
-W3C::SOAP::WSDL::Document::PortType - <One-line description of module's purpose>
+W3C::SOAP::WSDL::Document::PortType - Represents the port types in a WSDL document
 
 =head1 VERSION
 
-This documentation refers to W3C::SOAP::WSDL::Document::PortType version 0.09.
+This documentation refers to W3C::SOAP::WSDL::Document::PortType version 0.10.
 
 
 =head1 SYNOPSIS
@@ -66,10 +66,8 @@ This documentation refers to W3C::SOAP::WSDL::Document::PortType version 0.09.
 
 =head1 DESCRIPTION
 
-A full description of the module and its features.
-
-May include numerous subsections (i.e., =head2, =head3, etc.).
-
+A C<W3C::SOAP::WSDL::Document::PortType> object represents the portType tags
+in a WSDL document.
 
 =head1 SUBROUTINES/METHODS
 
