@@ -19,13 +19,13 @@ use W3C::SOAP::WSDL::Document::Port;
 
 extends 'W3C::SOAP::Document::Node';
 
-our $VERSION     = version->new('0.09');
+our $VERSION     = version->new('0.10');
 
 has ports => (
     is         => 'rw',
     isa        => 'ArrayRef[W3C::SOAP::WSDL::Document::Port]',
     builder    => '_ports',
-    lazy_build => 1,
+    lazy       => 1,
 );
 
 sub _ports {
@@ -49,11 +49,11 @@ __END__
 
 =head1 NAME
 
-W3C::SOAP::WSDL::Document::Service - <One-line description of module's purpose>
+W3C::SOAP::WSDL::Document::Service - Represents the services in a WSDL document
 
 =head1 VERSION
 
-This documentation refers to W3C::SOAP::WSDL::Document::Service version 0.09.
+This documentation refers to W3C::SOAP::WSDL::Document::Service version 0.10.
 
 
 =head1 SYNOPSIS
@@ -67,10 +67,8 @@ This documentation refers to W3C::SOAP::WSDL::Document::Service version 0.09.
 
 =head1 DESCRIPTION
 
-A full description of the module and its features.
-
-May include numerous subsections (i.e., =head2, =head3, etc.).
-
+A C<W3C::SOAP::WSDL::Document::Service> object represents the service tags
+in a WSDL document.
 
 =head1 SUBROUTINES/METHODS
 
